@@ -41,25 +41,26 @@ ASYNC = "OpenFuncAsync"
 def _cli(target, source, signature_type, host, port, debug, dry_run):
     ff = os.getenv("FUNC_CONTEXT", "")
     if signature_type == "http" and ff == "":
+        print("start http app")
         app = create_app(target, source, signature_type)
     else:
         _ctx = parse_function_context()
         port = _ctx.port
         if _ctx.runtime == KNATIVE_FUNC:
+            print("start http app")
             app = create_app(target, source, signature_type)
         elif _ctx.runtime == ASYNC:
             signature_type = "of"
+            print("start dapr app")
             app = create_dapr_app(target, source, signature_type, _ctx)
+            print("start dapr service")
+            create_dapr_server(app, port).run()
         else:
             raise RuntimeError("this runtime is not allow".format(_ctx.runtime))
     if dry_run:
         click.echo("Function: {}".format(target))
         click.echo("URL: http://{}:{}/".format(host, port))
         click.echo("Dry run successful, shutting down.")
-    elif ff != "":
-        try:
-            create_dapr_server(app, port).run()
-        except Exception:
-            raise RuntimeError("this is error happen")
     else:
+        print("start http service")
         create_server(app, debug).run(host, port)
